@@ -1,7 +1,7 @@
 #
 # This file is part of HTML-FormFu-ExtJS
 #
-# This software is Copyright (c) 2010 by Moritz Onken.
+# This software is Copyright (c) 2011 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
@@ -9,18 +9,14 @@
 #
 package HTML::FormFu::Element::ExtJS::TabPanel;
 BEGIN {
-  $HTML::FormFu::Element::ExtJS::TabPanel::VERSION = '0.077';
+  $HTML::FormFu::Element::ExtJS::TabPanel::VERSION = '0.090';
 }
 # ABSTRACT: FormFu class for ExtJS tab panels
 
-use strict;
-use base 'HTML::FormFu::Element::ExtJS::Panel';
+use Moose;
+extends 'HTML::FormFu::Element::ExtJS::Panel';
 
-sub new {
-    my $self = shift->next::method(@_);
-    $self->xtype( 'tabpanel' );
-    return $self;
-}
+has '+xtype' => ( default => 'tabpanel' );
 
 1;
 
@@ -34,7 +30,7 @@ HTML::FormFu::Element::ExtJS::TabPanel - FormFu class for ExtJS tab panels
 
 =head1 VERSION
 
-version 0.077
+version 0.090
 
 =head1 DESCRIPTION
 
@@ -182,7 +178,7 @@ Moritz Onken <onken@netcubed.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2010 by Moritz Onken.
+This software is Copyright (c) 2011 by Moritz Onken.
 
 This is free software, licensed under:
 
